pub struct ModelRequest {
pub messages: Vec<Message>,
pub tools: Vec<ToolDefinition>,
pub tool_choice: Option<ToolChoice>,
pub system_prompt: Option<String>,
}Expand description
A model invocation request visible to middleware.
Contains all parameters that will be sent to the ChatModel, plus
the optional system prompt managed by the agent builder.
Fields
messages: Vec<Message>tools: Vec<ToolDefinition>tool_choice: Option<ToolChoice>system_prompt: Option<String>Implementations
Sourceimpl ModelRequest
impl ModelRequest
Sourcepub fn to_chat_request(&self) -> ChatRequest
pub fn to_chat_request(&self) -> ChatRequest
Convert to a ChatRequest suitable for calling a ChatModel.